
# Table of Contents

1.  [Introduction](#org61820c1)



<a id="org61820c1"></a>

# Introduction

[Pfam](https://pfam.xfam.org/) is a database that collects information about protein families
and domains.  Profile hidden Markov models (HMMs) are used to
classify the protein families and hold information about
conservation and variability within family members.  Sequence logos
are graphical representations of biological sequence alignments or
HMMs, that give information about the conservation.

